/* malloc routines with error checking
 *
 * Copyright © 2007 Mozilla Corporation
 * Copyright © 2009 Carl D. Worth
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Authors:
 *	Vladimir Vukicevic <vladimir@pobox.com>
 *	Carl Worth <cworth@cworth.org>
 */

#include "xmalloc.h"
#include <stdio.h>

/* Allocate memory using malloc(), checking for errors.
 *
 * Errors: This function will exit(1) if out-of-memory occurs.
 */
void *
xmalloc (size_t size)
{
    void *ret;

    ret = malloc (size);
    if (ret == NULL) {
	fprintf (stderr, "Error: out of memory. Exiting.\n");
	exit (1);
    }

    return ret;
}

/* Re-allocate memory using realloc(), checking for errors.
 *
 * Errors: This function will exit(1) if out-of-memory occurs.
 */
void *
xrealloc (void *ptr, size_t size)
{
    void *ret;

    ret = realloc (ptr, size);
    if (ret == NULL) {
	fprintf (stderr, "Error: out of memory. Exiting.\n");
	exit (1);
    }

    return ret;
}
